Border class final

Constructors

Border({required bool enabled, required String topLeft, required String topRight, required String bottomLeft, required String bottomRight, required String horizontal, required String vertical})
const

Properties

bottomLeft String
final
bottomRight String
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
horizontal String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft String
final
topRight String
final
vertical String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

box → const Border
double → const Border
none → const Border
rounded → const Border
thick → const Border