KeyCode enum

Inheritance
Available extensions

Values

extended → const KeyCode
up → const KeyCode
down → const KeyCode
left → const KeyCode
home → const KeyCode
end → const KeyCode
pageUp → const KeyCode
pageDown → const KeyCode
insert → const KeyCode
delete → const KeyCode
backspace → const KeyCode
tab → const KeyCode
enter → const KeyCode
escape → const KeyCode
space → const KeyCode
f1 → const KeyCode
f2 → const KeyCode
f3 → const KeyCode
f4 → const KeyCode
f5 → const KeyCode
f6 → const KeyCode
f7 → const KeyCode
f8 → const KeyCode
f9 → const KeyCode
f10 → const KeyCode
f11 → const KeyCode
f12 → const KeyCode
rune → const KeyCode
unknown → const KeyCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyCode>
A constant List of the values in this enum, in order of their declaration.