ProgressModel class final

Simple determinate progress bar (0.0–1.0).

Inheritance

Constructors

ProgressModel({required double fraction, int width = 40, String label = '', ProgressStyles styles = ProgressStyles.defaults})

Properties

fraction double
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles ProgressStyles
final
width int
final

Methods

init() Cmd?
Optional command to run after the model is first installed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Msg msg) → (TeaModel, Cmd?)
Handle the next message; return the new model and an optional follow-up command.
override
view() View
Render the full program state.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited