ViewportModel class final

Scrollable content pane.

Inheritance

Constructors

ViewportModel({String content = '', int width = 80, int height = 24, int yOffset = 0, int xOffset = 0, bool softWrap = true})

Properties

atBottom bool
no setter
atTop bool
no setter
content String
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPercent double
no setter
softWrap bool
final
totalLines int
no setter
width int
final
xOffset int
final
yOffset int
final

Methods

init() Cmd?
Optional command to run after the model is first installed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollBy(int delta) ViewportModel
scrollTo(int line) ViewportModel
setContent(String newContent) ViewportModel
toString() String
A string representation of this object.
inherited
update(Msg msg) → (Model, Cmd?)
Handle the next message; return the new model and an optional follow-up command.
override
view() View
Render the full program state.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited