HelpStyles class final
Style configuration for HelpModel.
Constructors
- HelpStyles({Style title = const Style(), Style key = const Style(), Style description = const Style(), Style separator = const Style()})
-
const
Properties
- description → Style
-
Applied to key binding descriptions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Style
-
Applied to key binding labels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → Style
-
Applied to border separator lines (when HelpModel.showBorder is true).
final
- title → Style
-
Applied to the title / header.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const HelpStyles
- Beautiful defaults using the Catppuccin Mocha palette.